--- a/iaupdate/IAD/ui/src/iaupdateapplication.cpp Fri Apr 16 15:05:20 2010 +0300
+++ b/iaupdate/IAD/ui/src/iaupdateapplication.cpp Mon May 03 12:38:03 2010 +0300
@@ -1,5 +1,5 @@
/*
-* Copyright (c) 2007-2008 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
* All rights reserved.
* This component and the accompanying materials are made available
* under the terms of "Eclipse Public License v1.0"
@@ -11,65 +11,27 @@
*
* Contributors:
*
* Description: This module contains the implementation of CIAUpdateApplication
* class member functions.
*
*/
-
-
-#include <eikstart.h>
-#include "iaupdatedocument.h"
#include "iaupdateapplication.h"
-#include "iaupdateserver.h"
-
+#include "iaupdatemainwindow.h"
+#include "iaupdateengine.h"
-// ---------------------------------------------------------
-// CAppMngrApp::CreateDocumentL()
-// Creates CIAUpdateDocumentt object
-// ---------------------------------------------------------
-//
-CApaDocument* CIAUpdateApplication::CreateDocumentL()
- {
- // Create an IAUpdate document, and return a pointer to it
- CApaDocument* document = CIAUpdateDocument::NewL(*this);
- return document;
+IAUpdateApplication::IAUpdateApplication( int argc, char* argv[] ) :
+ HbApplication( argc, argv ),
+ mEngine (new IAUpdateEngine),
+ mMainWindow (new IAUpdateMainWindow())
+ {
+
+ // Connect view change signals to the view change slots
+ connect(&(*mEngine), SIGNAL(toMainView()), &(*mMainWindow), SLOT(toMainView()));
+ connect(&(*mEngine), SIGNAL(refresh(const RPointerArray<MIAUpdateNode>&, const RPointerArray<MIAUpdateFwNode>&,int)),
+ &(*mMainWindow), SLOT(refreshMainView(const RPointerArray<MIAUpdateNode>&, const RPointerArray<MIAUpdateFwNode>&,int)));
}
-
-// ---------------------------------------------------------
-// CIAUpdateApplication::AppDllUid
-// Returns application UID
-// ---------------------------------------------------------
-//
-TUid CIAUpdateApplication::AppDllUid() const
- {
- // Return the UID for the IAUpdate application
- return KUidIAUpdateApp;
- }
-
-// ---------------------------------------------------------
-// CIAUpdateApplication::NewAppServerL
-// Cretaes an instance of applicayion server class
-// ---------------------------------------------------------
-//
-void CIAUpdateApplication::NewAppServerL( CApaAppServer*& aAppServer )
+IAUpdateApplication::~IAUpdateApplication()
{
- aAppServer = CIAUpdateServer::NewL();
}
-
-
-// ================= OTHER EXPORTED FUNCTIONS ==============
-//
-// Create an application, and return a pointer to it
-LOCAL_C CApaApplication* NewApplication()
- {
- return new CIAUpdateApplication;
- }
-
-GLDEF_C TInt E32Main()
- {
- return EikStart::RunApplication(NewApplication);
- }
-
-// End of File
@@ -11,65 +11,27 @@
* Contributors:
*
-* Description: This module contains the implementation of CIAUpdateApplication
+* Description: This module contains the implementation of IAUpdateApplication
* class member functions.
*